==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/CodeDeploy/SkipWaitTimeForInstanceTermination.pm <==

package Paws::CodeDeploy::SkipWaitTimeForInstanceTermination;
  use Moose;
  has DeploymentId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'deploymentId' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SkipWaitTimeForInstanceTermination');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::SkipWaitTimeForInstanceTermination - Arguments for method SkipWaitTimeForInstanceTermination on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method SkipWaitTimeForInstanceTermination on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method SkipWaitTimeForInstanceTermination.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to SkipWaitTimeForInstanceTermination.

As an example:

  $service_obj->SkipWaitTimeForInstanceTermination(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 DeploymentId => Str

The ID of the blue/green deployment for which you want to skip the
instance termination wait time.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SkipWaitTimeForInstanceTermination in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/CodeDeploy/SkipWaitTimeForInstanceTermination.pm <==

package Paws::CodeDeploy::SkipWaitTimeForInstanceTermination;
  use Moose;
  has DeploymentId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'deploymentId' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SkipWaitTimeForInstanceTermination');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::SkipWaitTimeForInstanceTermination - Arguments for method SkipWaitTimeForInstanceTermination on L<Paws::CodeDeploy>

=head1 DESCRIPTION

This class represents the parameters used for calling the method SkipWaitTimeForInstanceTermination on the
L<AWS CodeDeploy|Paws::CodeDeploy> service. Use the attributes of this class
as arguments to method SkipWaitTimeForInstanceTermination.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to SkipWaitTimeForInstanceTermination.

=head1 SYNOPSIS

    my $codedeploy = Paws->service('CodeDeploy');
    $codedeploy->SkipWaitTimeForInstanceTermination(
      DeploymentId => 'MyDeploymentId',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/codedeploy/SkipWaitTimeForInstanceTermination>

=head1 ATTRIBUTES


=head2 DeploymentId => Str

The ID of the blue/green deployment for which you want to skip the
instance termination wait time.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SkipWaitTimeForInstanceTermination in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
